@@ -70,7 +70,7 @@ def strip_dirname(path):
 
 class Magma: 
     """A Simple Magma object created from a list of input file paths."""
-    def __init__(self, inputfilenames):
+    def __init__(self, inputfilenames, *args, **kwds):
         """A Simple Magma object created from a list of input file paths.
         
         @param inputfilenames: The paths to the files to hash.
@@ -98,7 +98,7 @@ class Magma:
             magnet = {}
             magnet[URN_PARAMETER_NAME] = {}
             magnet[URN_PARAMETER_NAME]['sha1'] = self.sha1[i]
-            magnet['name'] = strip_dirname(i)
+            magnet['filename'] = strip_dirname(i)
             list_of_magnets.append(magnet)
         magma[FILE_LIST_NAME] = list_of_magnets
         return magma
