@@ -44,7 +44,7 @@ from yaml import load, dump
 
 class Magma(object):
     """A Magma List."""
-    def __init__(self, magma_file=None, input_files=None, creator=None, data=None, yaml_data=None):
+    def __init__(self, magma_file=None, input_files=None, creator=None, data=None, yaml_data=None, *args, **kwds):
         """A Magma list. 
         
         @param magma_file: The path to the magma file, either absolute or relative the the location this script is invoked from. 
@@ -238,9 +238,9 @@ class MagmaFile(object):
     
     Provides some abstractions for files inside Magma objects. 
     
-        >>> magma_file = MagmaFile({"name": "input_file.txt", "urn": {"sha1": "3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G"}})
+        >>> magma_file = MagmaFile({"filename": "input_file.txt", "urn": {"sha1": "3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G"}})
         >>> print magma_file.data
-        {'urn': {'sha1': '3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G'}, 'name': 'input_file.txt'}
+        {'urn': {'sha1': '3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G'}, 'filename': 'input_file.txt'}
         >>> print magma_file.sha1_hash
         3UJCLAOIZVCNAIT7TQYFLAP7ZNFW6G2G
         >>> print magma_file.name
@@ -250,7 +250,7 @@ class MagmaFile(object):
 
     
     """
-    def __init__(self, data):
+    def __init__(self, data, *args, **kwds):
         """A file inside the magma list. 
         
         @param data: The data of this file. 
@@ -258,8 +258,8 @@ class MagmaFile(object):
         """
         #: All data of the file
         self.data = data
-        #: The name of the file, so we can easily print it. Every MagmaFile needs a name. 
-        self.name = self.data["name"]
+        #: The name of the file, so we can easily print it. Every MagmaFile needs a filename. 
+        self.name = self.data["filename"]
         #: The sha1 hash of the file. Every MagmaFile needs a sha1 hash. 
         self.sha1_hash = self.data[URN_PARAMETER_NAME]["sha1"]
         #: The magnet link of the file
